#!/usr/bin/env python
# -*- coding: utf-8 -*-

__modules__ = ['ROA']
#import ROA
from ROA import RunningOptimalAverage

__version__ = "1.2"


